
#include <stdio.h>
#include "picprog.h"


#define BLINK_ARRAY_LEN 29

static int blink_array[BLINK_ARRAY_LEN] =
{
0x2804,
0x0000,
0x0000,
0x0000,
0x1283,
0x0185,
0x3007,
0x0099,
0x1683,
0x303B,
0x0085,
0x1283,
0x3000,
0x0085,
0x2013,
0x3004,
0x0085,
0x2013,
0x280C,
0x30F9,
0x00A2,
0x30F9,
0x00A1,
0x0000,
0x0BA1,
0x2817,
0x0BA2,
0x2815,
0x0008
};


int main(void)
{
  int picAddress = 0;
  int osccal = 0x349C;
  int configword = 0x3181;

  
  if (ERROR == initLib())
  {
    printf("Could not init PIC library!\n");
    return ERROR;
  }

  
  setInactiveMode();
  printf("Attach adapter to parallel port and press RETURN.\n");
  getchar();
  setProgrammingMode();
  printf("Programming mode is ON now!\n");
  printf("Press RETURN again to start.\n");
  getchar();

  printf("Bulk erasing memory...\n");
  bulkErase();
  printf("Done!\n");
  setInactiveMode();
  printf("Press RETURN to start programming.\n");
  getchar();
  setProgrammingMode();

  
  for (picAddress = 0; picAddress < BLINK_ARRAY_LEN; ++picAddress)
  {
    if (ERROR == programAndVerify(blink_array[picAddress]))
    {
      printf("Error while programming address %X with data %X!\n", picAddress, blink_array[picAddress]);
      setInactiveMode();
      closeLib();
      return ERROR;
    }
    incrementAddress();
  }

  
  for (; picAddress < 0x3FF; ++picAddress)
    incrementAddress();

  if (ERROR == programAndVerify(osccal))
  {
    printf("Error while programming OSCCAL value %X!\n", osccal);
    setInactiveMode();
    closeLib();
    return ERROR;
  }

  
  loadConfig();

  for ( picAddress = 0x2000; picAddress < 0x2007; ++picAddress)
    incrementAddress();

  if (ERROR == programAndVerify(configword))
  {
    printf("Error while programming CONFIG value %X!\n", configword);
    setInactiveMode();
    closeLib();
    return ERROR;
  }

  setInactiveMode();
  closeLib();

  return 0;
}

